import { Driver } from "./Driver";
import { SchemaBuilder } from "../schema-builder/SchemaBuilder";
import { BaseDriver } from "./BaseDriver";
import { DriverOptions } from "./DriverOptions";
import { ObjectLiteral } from "../common/ObjectLiteral";
/**
 * This driver organizes work with mysql database.
 */
export declare class MysqlDriver extends BaseDriver implements Driver {
    connectionOptions: DriverOptions;
    readonly isResultsLowercase: boolean;
    /**
     * Mysql library.
     */
    private mysql;
    /**
     * Connection to mysql database.
     */
    private mysqlConnection;
    /**
     * Access to the native implementation of the database.
     */
    readonly native: any;
    /**
     * Access to the native connection to the database.
     */
    readonly nativeConnection: any;
    /**
     * Database name to which this connection is made.
     */
    readonly db: string;
    constructor(connectionOptions: DriverOptions, mysql?: any);
    /**
     * Creates a schema builder which can be used to build database/table schemas.
     */
    createSchemaBuilder(): SchemaBuilder;
    /**
     * Performs connection to the database based on given connection options.
     */
    connect(): Promise<void>;
    /**
     * Closes connection with database.
     */
    disconnect(): Promise<void>;
    /**
     * Escapes given value.
     */
    escape(value: any): any;
    /**
     * Executes a given SQL query.
     */
    query<T>(query: string, parameters?: any[]): Promise<T>;
    /**
     * Clears all tables in the currently connected database.
     */
    clearDatabase(): Promise<void>;
    buildParameters(sql: string, parameters: ObjectLiteral): any[];
    replaceParameters(sql: string, parameters: ObjectLiteral): string;
    protected checkIfConnectionSet(): void;
}
