"use strict";
const BaseEntityManager_1 = require("./BaseEntityManager");
/**
 * Entity manager supposed to work with any entity, automatically find its repository and call its methods, whatever
 * entity type are you passing.
 */
class EntityManager extends BaseEntityManager_1.BaseEntityManager {
    // -------------------------------------------------------------------------
    // Constructor
    // -------------------------------------------------------------------------
    constructor(connection) {
        super(connection);
    }
    persist(targetOrEntity, maybeEntity) {
        // todo: extra casting is used strange tsc error here, check later maybe typescript bug
        const target = arguments.length === 2 ? targetOrEntity : targetOrEntity.constructor;
        const entity = arguments.length === 2 ? maybeEntity : targetOrEntity;
        return this.obtainRepository(target).persist(entity);
    }
    remove(targetOrEntity, maybeEntity) {
        // todo: extra casting is used strange tsc error here, check later maybe typescript bug
        const target = arguments.length === 2 ? targetOrEntity : targetOrEntity.constructor;
        const entity = arguments.length === 2 ? maybeEntity : targetOrEntity;
        return this.obtainRepository(target).remove(entity);
    }
    /**
     * Finds entities that match given conditions.
     */
    find(entityClass, conditionsOrFindOptions, options) {
        if (conditionsOrFindOptions && options) {
            return this.obtainRepository(entityClass).find(conditionsOrFindOptions, options);
        }
        else if (conditionsOrFindOptions) {
            return this.obtainRepository(entityClass).find(conditionsOrFindOptions);
        }
        else {
            return this.obtainRepository(entityClass).find();
        }
    }
    /**
     * Finds entities that match given conditions.
     */
    findAndCount(entityClass, conditionsOrFindOptions, options) {
        if (conditionsOrFindOptions && options) {
            return this.obtainRepository(entityClass).findAndCount(conditionsOrFindOptions, options);
        }
        else if (conditionsOrFindOptions) {
            return this.obtainRepository(entityClass).findAndCount(conditionsOrFindOptions);
        }
        else {
            return this.obtainRepository(entityClass).findAndCount();
        }
    }
    /**
     * Finds first entity that matches given conditions.
     */
    findOne(entityClass, conditionsOrFindOptions, options) {
        if (conditionsOrFindOptions && options) {
            return this.obtainRepository(entityClass).findOne(conditionsOrFindOptions, options);
        }
        else if (conditionsOrFindOptions) {
            return this.obtainRepository(entityClass).findOne(conditionsOrFindOptions);
        }
        else {
            return this.obtainRepository(entityClass).findOne();
        }
    }
    /**
     * Finds entity with given id.
     */
    findOneById(entityClass, id, options) {
        return this.obtainRepository(entityClass).findOneById(id, options);
    }
    /**
     * Executes raw SQL query and returns raw database results.
     */
    query(query) {
        return this.connection.driver.query(query);
    }
    /**
     * Wraps given function execution (and all operations made there) in a transaction.
     */
    transaction(runInTransaction) {
        let runInTransactionResult;
        return this.connection.driver
            .beginTransaction()
            .then(() => runInTransaction())
            .then(result => {
            runInTransactionResult = result;
            return this.connection.driver.commitTransaction();
        })
            .then(() => runInTransactionResult);
    }
}
exports.EntityManager = EntityManager;

//# sourceMappingURL=EntityManager.js.map
