"use strict";
const TargetMetadata_1 = require("./TargetMetadata");
/**
 * This metadata interface contains all information about specific table.
 */
class TableMetadata extends TargetMetadata_1.TargetMetadata {
    // ---------------------------------------------------------------------
    // Constructor
    // ---------------------------------------------------------------------
    constructor(args) {
        super(args.target);
        // ---------------------------------------------------------------------
        // Private Properties
        // ---------------------------------------------------------------------
        /**
         * Indicates if this table is abstract or not. Regular tables can inherit columns from abstract tables.
         */
        this.tableType = "regular";
        this._name = args.name;
        this.tableType = args.type;
        this.orderBy = args.orderBy;
        this.primaryKeys = args.primaryKeys;
    }
    // ---------------------------------------------------------------------
    // Accessors
    // ---------------------------------------------------------------------
    /**
     * Table name in the database.
     */
    get name() {
        if (this.isClosureJunction && this._name)
            return this.entityMetadata.namingStrategy.closureJunctionTableName(this._name);
        // otherwise use target's table name
        const name = this.target instanceof Function ? this.target.name : this.target;
        return this.entityMetadata.namingStrategy.tableName(name, this._name);
    }
    /**
     * Checks if this table is regular (non abstract and non closure).
     */
    get isRegular() {
        return this.tableType === "regular";
    }
    /**
     * Checks if this table is abstract.
     */
    get isAbstract() {
        return this.tableType === "abstract";
    }
    /**
     * Checks if this table is a closure table.
     */
    get isClosure() {
        return this.tableType === "closure";
    }
    /**
     * Checks if this table is a junction table of the closure table.
     */
    get isClosureJunction() {
        return this.tableType === "closureJunction";
    }
    /**
     * Checks if this table is an embeddable table.
     */
    get isEmbeddable() {
        return this.tableType === "embeddable";
    }
}
exports.TableMetadata = TableMetadata;

//# sourceMappingURL=TableMetadata.js.map
